@@ -84,14 +84,12 @@
 					(WAN_TE3_BIT_LOS_ALARM |	\
 					 WAN_TE3_BIT_YEL_ALARM |	\
 					 WAN_TE3_BIT_OOF_ALARM))
-#else
+#endif
 
 #define IS_E3_ALARM(alarm)	((alarm) &				\
 					(WAN_TE3_BIT_YEL_ALARM |	\
 					 WAN_TE3_BIT_OOF_ALARM))
 
-#endif
-
 /******************************************************************************
 **			  FUNCTION DEFINITIONS
 ******************************************************************************/
@@ -188,10 +186,8 @@ static int sdla_te3_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notu
  */
 static int sdla_te3_polling(sdla_fe_t *fe)
 {
-    int err;
-
+       	int err;
 	err=sdla_te3_read_alarms(fe, WAN_FE_ALARM_READ|WAN_FE_ALARM_UPDATE);
-	
 	return err;
 }
 
@@ -1231,48 +1227,14 @@ static int sdla_te3_config(void *p_fe)
 	sdla_te3_cfg_t	*te3_cfg = &fe_cfg->cfg.te3_cfg;
 	u16		adptr_subtype;
 	unsigned char	data = 0x00;
-
-	DEBUG_EVENT("%s: TE3 Config\n",fe->name);
 	
 	WAN_ASSERT(fe->write_fe_reg == NULL);
 	WAN_ASSERT(fe->read_fe_reg == NULL);
 
-
-	if (fe_cfg->media == WAN_MEDIA_DS3) {
-		if (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout == 0xFF) {
-			/* If user set disc_cfg_timeout to 0xFF then disable feature */
-			fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout=0;
-		} else if (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout == 0) {
-			/* By default set timeout value to 10 sec */
-			fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout=10;
-		}
-
-		DEBUG_EVENT("%s: (T3) Disconnected timeout set to %i !\n",
-						fe->name, fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout);
-
-	} else {
-		if (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout &&
-			fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout != 0xFF) {
-			DEBUG_EVENT("%s: (E3) Disconnected timeout not supported !\n",
-						fe->name);
-		}
-		fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout=0;
-	}	
-
-
 	card->hw_iface.getcfg(card->hw, SDLA_ADAPTERSUBTYPE, &adptr_subtype);
 	
-	/* Read the part number */
 	data = READ_REG(0x02);
-	if (data != 0x07) {
-		DEBUG_EVENT("%s: Invalid T3/E3 Front End Chip Part number (%X)\n",
-				fe->name, data);
-		return -EINVAL;
-	}
-
-	/* Reset data variable */
-	data = 0x00;
-
+	
 	/* configure Line Interface Unit */
 	if (card->adptr_subtype == AFT_SUBTYPE_NORMAL){
 		sdla_te3_liu_config(fe, &te3_cfg->liu_cfg, fe->name);
@@ -1289,13 +1251,11 @@ static int sdla_te3_config(void *p_fe)
 		DEBUG_TE3("%s: (T3/E3) Media type DS3\n",
 				fe->name);
 		data |= BIT_OPMODE_DS3;
-		
 		break;
 	case WAN_MEDIA_E3:
 		DEBUG_TE3("%s: (T3/E3) Media type E3\n",
 				fe->name);
 		data &= ~BIT_OPMODE_DS3;
-		fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout=0;
 		break;
 	default:
 		DEBUG_EVENT("%s: Invalid Media type 0x%X\n",
@@ -1349,11 +1309,7 @@ static int sdla_te3_config(void *p_fe)
 				fe->name,fe_cfg->frame);
 		return -EINVAL;
 	}
-
-	/* NC: Internal LOS can fail and get stuck do not use it */
-#if 0
 	data |= BIT_OPMODE_INTERNAL_LOS;
-#endif
 	data |= (BIT_OPMODE_TIMREFSEL1 | BIT_OPMODE_TIMREFSEL0);
 	WRITE_REG(REG_OPMODE, data);
 
@@ -1392,10 +1348,8 @@ static int sdla_te3_config(void *p_fe)
 
 	DEBUG_EVENT("%s: %s disconnected!\n",
 					fe->name, FE_MEDIA_DECODE(fe));
+	sdla_te3_read_alarms(fe, 1);
 
-	if (fe_cfg->media == WAN_MEDIA_E3){
-		sdla_te3_read_alarms(fe, 1);
-	}
 	//sdla_te3_set_intr(fe);
 	return 0;
 }
@@ -1405,19 +1359,11 @@ static int sdla_te3_add_timer(sdla_fe_t* fe, unsigned long delay)
 {
 	int	err=0;
 
-	if (wan_test_bit(TE_TIMER_KILL,(void*)&fe->te3_param.critical)) {
-		DEBUG_EVENT("%s: Warning: sdla_te3_add_timer() timer killed!\n",fe->name);
-		return -EINVAL;
-
+	if (wan_test_bit(TE_TIMER_KILL,(void*)&fe->te_param.critical) ||
+	    wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical)) {
+		return 0;
 	}
 
-	if (wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical)) {
-		DEBUG_EVENT("%s: Warning: sdla_te3_add_timer() timer already running!\n",fe->name);
-		return -EBUSY;
-	}
-	
-	wan_set_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical);
-
 #if defined(__WINDOWS__)
 	/* delay is in MS, so it can be used directly by wan_add_timer() */
 	err = wan_add_timer(&fe->timer, delay);
@@ -1425,13 +1371,11 @@ static int sdla_te3_add_timer(sdla_fe_t* fe, unsigned long delay)
 	err = wan_add_timer(&fe->timer, delay * HZ / 1000);
 #endif
 
-	if (err) {
-		wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical);
-		DEBUG_EVENT("%s: Error: Failed to add timer err=%i !\n",fe->name,err);
+	if (err){
 		/* Failed to add timer */
 		return -EINVAL;
 	}
-
+	wan_set_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical);
 	return 0;	
 }
 
@@ -1448,32 +1392,27 @@ static void sdla_te3_timer(unsigned long pfe)
 	sdla_fe_t	*fe = (sdla_fe_t*)pfe;
 	sdla_t 		*card = (sdla_t*)fe->card;
 	wan_device_t	*wandev = &card->wandev;
-	int err;
 
 	DEBUG_TEST("[TE3] %s: TE3 timer!\n", fe->name);
-
-	if (wan_test_bit(TE_TIMER_KILL,(void*)&fe->te3_param.critical)){
-		DEBUG_EVENT("WARNING: %s: %s() Timer has been killed!\n", 
-					fe->name,__FUNCTION__);
-		wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical);
+	if (wan_test_bit(TE_TIMER_KILL,(void*)&fe->te_param.critical)){
+		wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical);
 		return;
 	}
-	if (!wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical)){
+	if (!wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical)){
 		/* Somebody clear this bit */
-		DEBUG_EVENT("WARNING: %s: %s() Timer bit is cleared (should never happened)!\n", 
-					fe->name,__FUNCTION__);
+		DEBUG_EVENT("WARNING: %s: Timer bit is cleared (should never happened)!\n", 
+					fe->name);
 		return;
 	}
-	wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical);
+	wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical);
 
 	if (wandev->fe_enable_timer){
 		wandev->fe_enable_timer(fe->card);
 	}
 
-	err=sdla_te3_add_timer(fe, 1000);
-	if (err) {
-		DEBUG_EVENT("%s: Error: Failed to sdla_te3_add_timer() %i\n",fe->name,err);
-	}
+	
+	sdla_te3_add_timer(fe, 1000);
+	
 
 	return;
 }
@@ -1485,7 +1424,7 @@ static int sdla_te3_post_init(void* pfe)
 
 
 	/* Initialize and start T1/E1 timer */
-	wan_set_bit(TE_TIMER_KILL,(void*)&fe->te3_param.critical);
+	wan_set_bit(TE_TIMER_KILL,(void*)&fe->te_param.critical);
 	
 	wan_init_timer(
 		&fe->timer, 
@@ -1493,7 +1432,7 @@ static int sdla_te3_post_init(void* pfe)
 	       	(wan_timer_arg_t)fe);
 
 	/* Initialize T1/E1 timer */
-	wan_clear_bit(TE_TIMER_KILL,(void*)&fe->te3_param.critical);
+	wan_clear_bit(TE_TIMER_KILL,(void*)&fe->te_param.critical);
 
 	/* Start T1/E1 timer */
 	if (IS_E3(&fe->fe_cfg)){
@@ -1510,11 +1449,11 @@ static int sdla_te3_pre_release(void* pfe)
 
 
 	/* Kill TE timer poll command */
-	wan_set_bit(TE_TIMER_KILL,(void*)&fe->te3_param.critical);
-	if (wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical)){
+	wan_set_bit(TE_TIMER_KILL,(void*)&fe->te_param.critical);
+	if (wan_test_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical)){
 		wan_del_timer(&fe->timer);
 	}
-	wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te3_param.critical);
+	wan_clear_bit(TE_TIMER_RUNNING,(void*)&fe->te_param.critical);
 
 	return 0;
 }
